@@ -10,7 +10,7 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 
-config etc/rc.d/rc.modules-2.6.13.new
+config etc/rc.d/rc.modules-2.6.17.13.new
 
 # If rc.modules is a real file, back it up:
 if [ -r etc/rc.d/rc.modules -a ! -L etc/rc.d/rc.modules ]; then
@@ -21,15 +21,15 @@ fi
 # of this script on your own...
 if [ ! -L etc/rc.d/rc.modules ]; then
   ( cd etc/rc.d ; rm -rf rc.modules )
-  ( cd etc/rc.d ; ln -sf rc.modules-2.6.13 rc.modules )
+  ( cd etc/rc.d ; ln -sf rc.modules-2.6.17.13 rc.modules )
 fi
 
 # A good idea whenever kernel modules are added or changed:
 if [ -x sbin/depmod ]; then
-  chroot . /sbin/depmod -a 1> /dev/null 2> /dev/null
+  chroot . /sbin/depmod -a 2.6.17.13 1> /dev/null 2> /dev/null
 fi
 
-( cd lib/modules/2.6.13 ; rm -rf build )
-( cd lib/modules/2.6.13 ; ln -sf /usr/src/linux-2.6.13 build )
-( cd lib/modules/2.6.13 ; rm -rf source )
-( cd lib/modules/2.6.13 ; ln -sf /usr/src/linux-2.6.13 source )
+( cd lib/modules/2.6.17.13 ; rm -rf build )
+( cd lib/modules/2.6.17.13 ; ln -sf /usr/src/linux-2.6.17.13 build )
+( cd lib/modules/2.6.17.13 ; rm -rf source )
+( cd lib/modules/2.6.17.13 ; ln -sf /usr/src/linux-2.6.17.13 source )
